@@ -1,12 +1,13 @@
 import typing
 from concurrent.futures import Future
+from typing import Optional
 
 from taskhawk.backends.base import TaskhawkPublisherBaseBackend
 from taskhawk.backends.utils import get_publisher_backend
 from taskhawk.models import Message
 
 
-def publish(message: Message, backend: TaskhawkPublisherBaseBackend = None) -> typing.Union[str, Future]:
+def publish(message: Message, backend: Optional[TaskhawkPublisherBaseBackend] = None) -> typing.Union[str, Future]:
     """
     Publishes a message on Taskhawk topic
     """
